#-----------------------------------------------------------------------------
# Name        :   Change number of segments of Bezier Curve
# Description :   Increase or decrease the number of segments representing the Bezier Curve
# Context Menu:   Change Number of Segments
# Usage       :   Select an existing nonrational or rational Bezier curve, arc, circle
#                 or line and choose Change Number of Segments to activate the tool.
#             :   Then enter the new number of segments greater than 0 and less than 100 
#                 in the Value Control Box(VCB).  
# Date        :   02/08/2015
# Type        :   Tool
#-----------------------------------------------------------------------------

# First we pull in the standard API hooks.
require 'sketchup.rb'
Sketchup::require 'jps_beziercurvemanager/ManipDirectly'

#-----------------------------------------------------------------------------
module JPS::BezierCurveManager

#-----------------------------------------------------------------------------
# Define the tool class for changing the number of segments of Bezier curves.
class JPS_ChangeBezierCurveNumSegTool < JPS_ManipulateBezierCurveTool

  def activate
    super()
    Sketchup::set_status_text "Type the number of segments used to represent the selected Bezier Curve and press Enter or Return", SB_PROMPT
    Sketchup::set_status_text "Number of Segments", SB_VCB_LABEL
    Sketchup::set_status_text @numseg, SB_VCB_VALUE
    @allow_change_status_text_on_mouse_move = false
  end

  # For this tool, allow vcb text entry while the tool is active.
  def enableVCB?
    return true
  end

  def onUserText(text, view)
    # get the number of segments from the text
    newnumseg = text.to_i
    if(newnumseg < 1)
      UI.messagebox "Minimum number of segments is 1"
      Sketchup::set_status_text @numseg, SB_VCB_VALUE
    elsif(newnumseg > 99)
      UI.messagebox "Maximum number of segments is 99.\nPlease consider subdividing the curve using the Subdivide tool in this extension."
      Sketchup::set_status_text @numseg, SB_VCB_VALUE
    elsif(newnumseg == @numseg)
      UI.messagebox "New number of segments should be different than current number"
      Sketchup::set_status_text @numseg, SB_VCB_VALUE
    elsif(newnumseg > @numseg)
      @crvpts = JPS::BezierCurveManager.points(@pts, @weights, newnumseg)
      model = Sketchup.active_model
      model.selection.clear
      model.start_operation("Smoothen Bezier Curve", true, true)
      convert_arccurve_or_edge_to_bezcurve()
      while(newnumseg > @numseg)
        @curve.each_edge { |e| 
          if (newnumseg > @numseg)
            e.split(0.5)
            @numseg += 1
          end
        }
      end
      model.start_operation("ssup", true)
      @curve.move_vertices @crvpts
      model.commit_operation
      model.selection.add @curve.edges 
      activate()
    elsif(newnumseg < @numseg)
      @crvpts = JPS::BezierCurveManager.points(@pts, @weights, newnumseg)
      model = Sketchup.active_model
      model.selection.clear
      entities = model.active_entities
      model.start_operation "Coarsen Bezier Curve"
        @curve.each_edge { |e| e.erase! }
        # create the new curve
        edges = entities.add_curve(@crvpts);
        @curve = edges[0].curve
        @curve.set_attribute "jps", "crvtype", "Rational Bezier"
        @curve.set_attribute "jps", "crvpts", @pts
        @curve.set_attribute "jps", "weights",  @weights
      model.commit_operation
      model.selection.add edges
      activate()
    else 
      UI.beep
      Sketchup::set_status_text @degree, SB_VCB_VALUE
    end
  end

end # class JPS_ChangeBezierCurveDegreeTool
end #module JPS::BezierCurveManager