﻿#-----------------------------------------------------------------------------
# Name        :   Bezier Curve Manager Menus
# Description :   Governing menu creation script for the Bezier Curve Manager Tools
# Menu Item   :   None
# Context Menu:   None
# Usage       :   None - Loads the Bezier Curve Manager tools one by one and adds their menu items
# Date        :   12/20/14
# Type        :   Loader
#-----------------------------------------------------------------------------
require 'sketchup.rb'
#-----------------------------------------------------------------------------
module JPS
module BezierCurveManager

require 'jps_beziercurvemanager/su_bezier.rb'
Sketchup::require 'jps_beziercurvemanager/ManipDirectly'
Sketchup::require 'jps_beziercurvemanager/ChangeDegree'
Sketchup::require 'jps_beziercurvemanager/AddDelCtrlPnts'
Sketchup::require 'jps_beziercurvemanager/ChangeNumSeg'
Sketchup::require 'jps_beziercurvemanager/SubDivide'
#------------------------------------------------------------------------------
def self.jps_bezcurve_validation_proc()
  if (self.selected_curve())
    return MF_ENABLED
  else
    return MF_GRAYED
  end
end

#------------Toolbar, Tools Menu and Context Menu ---------------------
jps_bezcurve_tb = UI::Toolbar.new("编辑贝兹曲线")

if( not file_loaded?("jps_beziercurvemanager") )
  jps_tools_bezcurve_submenu = UI.menu("Tools").add_submenu("编辑贝兹曲线")    
  jps_manip_bezcurve_tool = JPS_ManipulateBezierCurveTool.new
  cmd1 = UI::Command.new("调整控制点") { Sketchup::active_model.select_tool jps_manip_bezcurve_tool }
  cmd1.small_icon = "Images/tbManipDirectlySmall.png"
  cmd1.large_icon = "Images/tbManipDirectlyLarge.png"
  cmd1.tooltip = "调整控制点：用权重值作为影响曲线形状的因素"
  cmd1.status_bar_text = "通过更改权重点的位置 去改变 曲线的形状。"
  cmd1.set_validation_proc {
    if (jps_manip_bezcurve_tool::is_tool_active())
      MF_CHECKED
    else
      jps_bezcurve_validation_proc()
    end }
  jps_tools_bezcurve_submenu.add_item(cmd1)
  jps_bezcurve_tb.add_item(cmd1)
  jps_change_bezcurve_degree_tool = JPS_ChangeBezierCurveDegreeTool.new
  cmd2 = UI::Command.new("更改曲线角度") { Sketchup::active_model.select_tool jps_change_bezcurve_degree_tool }
  cmd2.small_icon = "Images/tbChangeDegreeSmall.png"
  cmd2.large_icon = "Images/tbChangeDegreeLarge.png"
  cmd2.tooltip = "更改曲线角度"
  cmd2.status_bar_text = "更改所选贝兹曲线的控制点的角度和数量。"
  cmd2.set_validation_proc {
    if (jps_change_bezcurve_degree_tool::is_tool_active())
      MF_CHECKED
    else
      jps_bezcurve_validation_proc()
    end }
  jps_tools_bezcurve_submenu.add_item(cmd2)
  jps_bezcurve_tb.add_item(cmd2)
  
  jps_add_del_cntrl_points_bezcurve_tool = JPS_AddDelCtrlPntsBezierCurveTool.new
  cmd3 = UI::Command.new("增删控制点") { Sketchup::active_model.select_tool jps_add_del_cntrl_points_bezcurve_tool }
  cmd3.small_icon = "Images/tbAddDelCtrlPntsSmall.png"
  cmd3.large_icon = "Images/tbAddDelCtrlPntsLarge.png"
  cmd3.tooltip = "增删控制点"
  cmd3.status_bar_text = "增加或者删除所选贝兹曲线的控制点。"
  cmd3.set_validation_proc {
    if (jps_add_del_cntrl_points_bezcurve_tool::is_tool_active())
      MF_CHECKED
    else
      jps_bezcurve_validation_proc()
    end }
  jps_tools_bezcurve_submenu.add_item(cmd3)
  jps_bezcurve_tb.add_item(cmd3)
  
  jps_change_bezcurve_numseg_tool = JPS_ChangeBezierCurveNumSegTool.new
  cmd4 = UI::Command.new("修改曲线段数") { Sketchup::active_model.select_tool jps_change_bezcurve_numseg_tool }
  cmd4.small_icon = "Images/tbChangeNumSegSmall.png"
  cmd4.large_icon = "Images/tbChangeNumSegLarge.png"
  cmd4.tooltip = "修改曲线段数"
  cmd4.status_bar_text = "更改贝兹曲线的段数"
  cmd4.set_validation_proc {
    if (jps_change_bezcurve_numseg_tool::is_tool_active())
      MF_CHECKED
    else
      jps_bezcurve_validation_proc()
    end }
  jps_tools_bezcurve_submenu.add_item(cmd4)
  jps_bezcurve_tb.add_item(cmd4)
  jps_subdivide_bezcurve_tool = JPS_SubDivideBezierCurveTool.new
  cmd5 = UI::Command.new("细分曲线") { Sketchup::active_model.select_tool jps_subdivide_bezcurve_tool }
  cmd5.small_icon = "Images/tbSubDivideSmall.png"
  cmd5.large_icon = "Images/tbSubDivideLarge.png"
  cmd5.tooltip = "细分曲线"
  cmd5.status_bar_text = "细分被选择的贝兹曲线"
  cmd5.set_validation_proc {
    if (jps_subdivide_bezcurve_tool::is_tool_active())
      MF_CHECKED
    else
      jps_bezcurve_validation_proc()
    end }
  jps_tools_bezcurve_submenu.add_item(cmd5)
  jps_bezcurve_tb.add_item(cmd5)
  # Add a context menu handler with the Bezier Curve Manager tools
  UI.add_context_menu_handler do |menu|
    if( selected_curve() )
      jps_context_bezcurve_submenu = menu.add_submenu("Bezier Curve Manager")
      jps_context_bezcurve_submenu.add_item(cmd1)
      jps_context_bezcurve_submenu.add_item(cmd2)
      jps_context_bezcurve_submenu.add_item(cmd3)
      jps_context_bezcurve_submenu.add_item(cmd4)
      jps_context_bezcurve_submenu.add_item(cmd5)
    end
  end
         
  # Let Ruby know we have loaded this file
  file_loaded("jps_beziercurvemanager")
end
if jps_bezcurve_tb.get_last_state == TB_NEVER_SHOWN
  # Hide toolbar at first startup
  jps_bezcurve_tb.hide
else
  jps_bezcurve_tb.restore
  # Per bug 2902434, adding a timer call to restore the toolbar. This
  # fixes a toolbar resizing regression on PC as the restore() call
  # does not seem to work as the script is first loading.
  UI.start_timer(0.1, false) {
    jps_bezcurve_tb.restore
  }
end

end # module BezierCurveManager
end # module JPS
